# RWSkit

This is a collection of utilities that I have found myself recreating over and over again in different projects.

The following `extras` are defined to help minimize dependencies.

config
: Dataclass extensions intended to be useful for configuration objects.
  These extensions primarily involve loading and saving dataclasses using YAML.

numpy
: Utilities for working with [numpy](https://numpy.org/).

pandas
: Utilities for working with [pandas](https://pandas.pydata.org/).

sqlalchemy
: Utilities for working with [sqlalchemy](https://www.sqlalchemy.org/).

benchmarking
: A benchmarking utility.

notebooks
: A small collection notebooks that I primarily use to take notes.


